@@ -90,8 +90,7 @@ class MasterCravatConverter(object):
         self.chromdict = {
             "chrx": "chrX",
             "chry": "chrY",
-            "chrMT": "chrM",
-            "chrMt": "chrM",
+            "chrMt": "chrMT",
             "chr23": "chrX",
             "chr24": "chrY",
         }
@@ -99,6 +98,7 @@ class MasterCravatConverter(object):
         self.vtracker = VTracker(deduplicate=not (self.unique_variants))
         self.wgsreader = cravat.get_wgs_reader(assembly="hg38")
         self.crs_def = constants.crs_def.copy()
+        self.error_lines = 0
 
     def _parse_cmd_args(self, inargs, inkwargs):
         """ Parse the arguments in sys.argv """
@@ -288,7 +288,10 @@ class MasterCravatConverter(object):
                 first_file = self.first_input_file()
                 first_file.seek(0)
                 for converter_name, converter in self.converters.items():
-                    check_success = converter.check_format(first_file)
+                    try:
+                        check_success = converter.check_format(first_file)
+                    except:
+                        check_success = False
                     first_file.seek(0)
                     if check_success:
                         valid_formats.append(converter_name)
@@ -419,20 +422,16 @@ class MasterCravatConverter(object):
             converter.setup(f)
             if self.pipeinput == False:
                 f.seek(0)
-            read_lnum = 0
-            num_errors = 0
             if self.pipeinput:
                 cur_fname = STDIN
             else:
                 cur_fname = os.path.basename(f.name)
-            for l in f:
+            for read_lnum, l, all_wdicts in converter.convert_file(f, exc_handler=self._log_conversion_error):
                 samp_prefix = cur_fname
-                read_lnum += 1
                 try:
                     # all_wdicts is a list, since one input line can become
                     # multiple output lines. False is returned if converter
                     # decides line is not an input line.
-                    all_wdicts = converter.convert_line(l)
                     if all_wdicts is BaseConverter.IGNORE:
                         continue
                     total_lnum += 1
@@ -446,6 +445,9 @@ class MasterCravatConverter(object):
                             if chrom is not None:
                                 if not chrom.startswith("chr"):
                                     chrom = "chr" + chrom
+                                if not self.do_liftover:
+                                    if chrom.lower() == "chrmt":
+                                        chrom = "chrM"
                                 wdict["chrom"] = self.chromdict.get(chrom, chrom)
                                 if multiple_files:
                                     if wdict["sample_id"]:
@@ -522,7 +524,7 @@ class MasterCravatConverter(object):
                                             wdict, no_unique_var
                                         )
                                     except Exception as e:
-                                        self._log_conversion_error(read_lnum, l, e)
+                                        self._log_conversion_error(read_lnum, l, e, full_line_error=False)
                                     no_unique_var += 1
                                 if UID not in UIDMap:
                                     # For this input line, only write to the .crm if the UID has not yet been written to the map file.
@@ -539,7 +541,6 @@ class MasterCravatConverter(object):
                     else:
                         raise ExpectedException("No valid alternate allele was found in any samples.")
                 except Exception as e:
-                    num_errors += 1
                     self._log_conversion_error(read_lnum, l, e)
                     continue
             f.close()
@@ -552,13 +553,13 @@ class MasterCravatConverter(object):
                     ),
                 )
                 last_status_update_time = cur_time
-        self.logger.info("error lines: %d" % num_errors)
+        self.logger.info("error lines: %d" % self.error_lines)
         self._close_files()
         self.end()
         if self.status_writer is not None:
             self.status_writer.queue_status_update("num_input_var", total_lnum)
             self.status_writer.queue_status_update("num_unique_var", write_lnum)
-            self.status_writer.queue_status_update("num_error_input", num_errors)
+            self.status_writer.queue_status_update("num_error_input", self.error_lines)
         end_time = time.time()
         self.logger.info("finished: %s" % time.asctime(time.localtime(end_time)))
         runtime = round(end_time - start_time, 3)
@@ -573,7 +574,10 @@ class MasterCravatConverter(object):
     def liftover(self, chrom, pos, ref, alt):
         reflen = len(ref)
         altlen = len(alt)
-        if reflen == 1 and altlen == 1:
+        if chrom == "chrMT":
+            newchrom = "chrM"
+            newpos = pos
+        elif reflen == 1 and altlen == 1:
             res = self.lifter.convert_coordinate(chrom, pos - 1)
             if res is None or len(res) == 0:
                 raise LiftoverFailure("Liftover failure")
@@ -638,12 +642,14 @@ class MasterCravatConverter(object):
             newalt = alt
         return [newchrom, newpos, newref, newalt]
 
-    def _log_conversion_error(self, ln, line, e):
+    def _log_conversion_error(self, ln, line, e, full_line_error=True):
         """Log exceptions thrown by primary converter.
         All exceptions are written to the .err file with the exception type
         and message. Exceptions are also written to the log file once, with the
         traceback.
         """
+        if full_line_error:
+            self.error_lines += 1
         err_str = traceback.format_exc().rstrip()
         if err_str not in self.unique_excs:
             self.unique_excs.append(err_str)
